# FastAPI Cachette

[![Build Status](https://travis-ci.com/aekasitt/fastapi-cachette.svg?branch=master)](https://app.travis-ci.com/github/aekasitt/fastapi-cachette)
[![Package Vesion](https://img.shields.io/pypi/v/fastapi-cachette)](https://pypi.org/project/fastapi-cachette)
[![Format](https://img.shields.io/pypi/format/fastapi-cachette)](https://pypi.org/project/fastapi-cachette)
[![Python Version](https://img.shields.io/pypi/pyversions/fastapi-cachette)](https://pypi.org/project/fastapi-cachette)
[![License](https://img.shields.io/pypi/l/fastapi-cachette)](https://pypi.org/project/fastapi-cachette)

## Features

Cache Implementation Extension for FastAPI Asynchronous Web Framework
Most of the Backend implementation is directly lifted from [fastapi-cache](https://github.com/long2ice/fastapi-cache) by [@long2ice](https://github.com/long2ice)

## Installation

The easiest way to start working with this extension with pip

```bash
pip install fastapi-cachette
# or
poetry add fastapi-cachette
```

## Getting Started

The following examples show you how to integrate this extension to a FastAPI App

### To Be Continued
